##  Using the Circle Map Report
The Interface Circle Map report provides a clear visual representation of dependencies and risks and helps determine where APIs are needed. You can simply hover over the Applications to see how they are related to other Applications.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27509b617a4410149cbfaa648c184d9e_LowRes.png)
Color-coded lines indicate whether an application is a provider of an interface, or a consumer, or both. It can be both when an application has more than one interface with another application, serving as both provider and consumer. This information can be used to improve the overall integration architecture.
